| emplace_after | R Documentation |
Add an element to a forward list by reference in place.
emplace_after(x, value, position)
x |
A CppForwardList object. |
value |
Value to add to |
position |
Index after which to insert the element. Indices start at 1. The function does not perform bounds checks. Indices outside |
The emplace methods only add single elements. Use insert to add multiple elements in one call.
Invisibly returns NULL.
emplace, emplace_back, emplace_front, insert.
l <- cpp_forward_list(4:6)
l
# 4 5 6
emplace_after(l, 10L, 2)
l
# 4 5 10 6
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.