| emplace_back | R Documentation |
Add an element to the back of a container by reference in place.
emplace_back(x, value)
x |
A CppVector, CppDeque, CppList object. |
value |
A value to add to |
The emplace methods only add single elements. Use insert to add multiple elements in one call.
Invisibly returns NULL.
emplace, emplace_after, emplace_front, insert, pop_back, push_back.
v <- cpp_vector(4:6)
v
# 4 5 6
emplace_back(v, 12L)
v
# 4 5 6 12
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.