| unique | R Documentation |
Erases consecutive duplicated values from the container by reference.
unique(x, incomparables, ...)
x |
A CppForwardList or CppList object. |
incomparables |
Ignored. |
... |
Ignored. |
Duplicated, non-consecutive elements are not removed.
incomparables and ... are only included for compatibility with the generic base::unique method and have no effect.
Returns the number of deleted elements.
erase, remove., sort.
l <- cpp_forward_list(c(4, 5, 6, 6, 4))
l
# 4 5 6 6 4
unique(l)
# [1] 1
l
# 4 5 6 4
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.