| assign | R Documentation |
Replace all elements in a container by reference.
assign(x, value, pos, envir, inherits, immediate)
x |
A CppVector, CppDeque, CppForwardList, or CppList object. |
value |
A vector. It is called |
pos |
Ignored. |
envir |
Ignored. |
inherits |
Ignored. |
immediate |
Ignored. |
Replaces all elements in x with the elements in value.
The parameters pos, envir, inherits, and immediate are only included for compatibility with the generic base::assign
method and have no effect.
Invisibly returns NULL.
emplace, emplace_after, emplace_back, emplace_front, insert, insert_after, insert_or_assign.
v <- cpp_vector(4:9)
v
# 4 5 6 7 8 9
assign(v, 12:14)
v
# 12 13 14
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.