| emplace_front | R Documentation |
Add an element to the front of a container by reference in place.
emplace_front(x, value)
x |
A CppDeque, CppForwardList, or CppList object. |
value |
A value to add to |
The emplace methods only add single elements. Use insert to add multiple elements in one call.
Invisibly returns NULL.
emplace, emplace_after, emplace_back, insert, pop_front, push_front.
l <- cpp_forward_list(4:6)
l
# 4 5 6
emplace_front(l, 12L)
l
# 12 4 5 6
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.